==> php-residence_0.2.4.tar.gz: php-residence/includes/sett_gio.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


$tipo_periodi = pg_exec("select * from anni where idanni = $anno");
$tipo_periodi = pg_result($tipo_periodi,0,tipo_periodi);
if ($tipo_periodi == "g") {
$parola_settimanale = "giornaliero";
$parola_settimanali = "giornalieri";
$parola_settimane = "giorni";
$parola_settimana = "giorno";
$parola_settiman = "giorn";
$parola_sett = "gio";
$parola_le = "i";
$parola_Le = "I";
$parola_la = "il";
$parola_La = "Il";
$lettera_e = "i";
$lettera_a = "o";
$lettera_s = "g";
} # fine if ($tipo_periodi == "g")
else {
$parola_settimanale = "settimanale";
$parola_settimanali = "settimanali";
$parola_settimane = "settimane";
$parola_settimana = "settimana";
$parola_settiman = "settiman";
$parola_sett = "sett";
$parola_le = "le";
$parola_Le = "Le";
$parola_la = "la";
$parola_La = "La";
$lettera_e = "e";
$lettera_a = "a";
$lettera_s = "s";
} # fine else if ($tipo_periodi == "g")


?>

==> php-residence_0.3.tar.gz: php-residence/includes/sett_gio.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


$tipo_periodi = esegui_query("select * from anni where idanni = $anno");
$tipo_periodi = risul_query($tipo_periodi,0,tipo_periodi);
if ($tipo_periodi == "g") {
$parola_settimanale = "giornaliero";
$parola_settimanali = "giornalieri";
$parola_settimane = "giorni";
$parola_settimana = "giorno";
$parola_settiman = "giorn";
$parola_sett = "gio";
$parola_le = "i";
$parola_Le = "I";
$parola_la = "il";
$parola_La = "Il";
$lettera_e = "i";
$lettera_a = "o";
$lettera_s = "g";
} # fine if ($tipo_periodi == "g")
else {
$parola_settimanale = "settimanale";
$parola_settimanali = "settimanali";
$parola_settimane = "settimane";
$parola_settimana = "settimana";
$parola_settiman = "settiman";
$parola_sett = "sett";
$parola_le = "le";
$parola_Le = "Le";
$parola_la = "la";
$parola_La = "La";
$lettera_e = "e";
$lettera_a = "a";
$lettera_s = "s";
} # fine else if ($tipo_periodi == "g")


?>
